@@ -1,6 +1,6 @@
 """A set of components for Panel Sharing"""
 from .authentication import Authentication
-from .build_project import BuildProject
+from .build_project import ProjectBuilder
 from .gallery import Gallery
 from .other import about, faq, iframe
 from .settings_editor import settings_editor
